@@ -13,7 +13,7 @@
 ---------------------------------------------*/
 function creeNouvGrp($nomGrp,$details) {
 	global $mysqli;
-	
+
 	if (trim($nomGrp)=="") return "Nom du groupe vide !";
 	if ($res=$mysqli->query("SELECT nom FROM es_groupes WHERE nom LIKE '$nomGrp'")) {
 		if ($res->num_rows==0) {//le nom n'existe pas encore - on créé le groupe
@@ -33,7 +33,7 @@ function creeNouvGrp($nomGrp,$details) {
 ---------------------------------------------*/
 function recupGrp($choix=0) {
 	global $mysqli;
-	
+
 	if ($choix==0) $leChoix1=$leChoix2='1';
 	else {
 		$leChoix1='groupe_ID='.$choix;
@@ -64,7 +64,7 @@ function recupGrp($choix=0) {
 ---------------------------------------------*/
 function recupCompoGrp($idGrp) {
 	global $mysqli;
-	
+
 	$tMach=array();
 	if ($res=$mysqli->query("SELECT es_machines.nom,machine_ID FROM es_machines,es_grp_machines WHERE machine_ID=ID_machine AND groupe_ID='".$idGrp."' ORDER BY es_machines.nom")) {
 		while (list($_nomM,$_machID)=$res->fetch_row()) {
@@ -84,7 +84,7 @@ function recupCompoGrp($idGrp) {
 ---------------------------------------------*/
 function recupMachines($idMach=0) {
 	global $mysqli;
-	
+
 	if ($idMach==0) $choixMachine='1';
 	else $choixMachine="ID_machine=$idMach";
 	$tMach=array();
@@ -107,7 +107,7 @@ function recupMachines($idMach=0) {
 
 function ajouteMachinesGroupe($idGroupe,$idMach){
 	global $mysqli;
-	
+
 	if (!is_array($idMach)) $idMach=array($idMach);
 	if (count($idMach)>0) foreach ($idMach as $_ajoutMachine) {
 		$query="INSERT INTO es_grp_machines SET groupe_ID='$idGroupe' , machine_ID='$_ajoutMachine'";
@@ -127,7 +127,7 @@ function ajouteMachinesGroupe($idGroupe,$idMach){
 
 function supprimeMachinesGroupe($idGroupe,$idMach){
 	global $mysqli;
-	
+
 	if (!is_array($idMach)) $idMach=array($idMach);
 	if (count($idMach)>0) foreach ($idMach as $_ajoutMachine) {
 		$query="DELETE FROM es_grp_machines WHERE groupe_ID='$idGroupe' AND machine_ID='$_ajoutMachine'";
@@ -146,7 +146,7 @@ function supprimeMachinesGroupe($idGroupe,$idMach){
 ---------------------------------------------*/
 function majNomGroupe($choixG,$nomG,$detailsG) {
 	global $mysqli;
-	
+
 	if ($res=$mysqli->query("SELECT nom FROM es_groupes WHERE nom LIKE '$nomG'")) {
 		if ($res->num_rows==0) {//le nom n'existe pas encore - on créé le groupe
 			$query="UPDATE es_groupes SET nom='$nomG',details='$detailsG' WHERE ID_groupe='$choixG'";
@@ -167,7 +167,7 @@ function majNomGroupe($choixG,$nomG,$detailsG) {
 ---------------------------------------------*/
 function suppGrp($choixG) {
 	global $mysqli;
-	
+
 	$mysqli->query("DELETE FROM es_grp_machines WHERE groupe_ID=".$choixG);
 	$mysqli->query("DELETE FROM es_groupes WHERE ID_groupe=".$choixG);
 }
@@ -330,17 +330,17 @@ function afficheListe($tListe) {
 }
 
 //lecture du fichier copie_machines.db pour menu déroulant liste noms stations
-function listeStations($fic,$stationselect) {	
+function listeStations($fic,$stationselect) {
 	if (is_array($stationselect)) foreach ($stationselect as $_lig) {
 		if (trim($_lig)!="") $tL[]=trim($_lig);
 	}
-	
+
 	//si le fichier copie_machine.db n'existe pas ou qu'il est vide, on sort...
 	if (!file_exists($fic) || filesize($fic) == 0) {
 		echo '<option disabled="1">aucune station trouvée...</option>';
 		return;
 	}
-	
+
 	$id_fichier = fopen($fic,"r");
 	$contenu = fread($id_fichier, filesize($fic));
 	fclose($id_fichier);
@@ -371,20 +371,22 @@ function listeStations($fic,$stationselect) {
 			else $noms[] = $tabligne[0];
 		}
 		//$noms[] = $tabligne[0];
-		
+
 		if (isset($noms)) usort($noms, "strcasecmp");
 	}
-	foreach ($noms as $nom) {
-		$desac=$txtPb="";
-		if (in_array($nom, $nomsPb)) {
-			$desac=" disabled";
-			//$txtPb=" (adresse inconnue)";
-		}
-		if (in_array($nom, $tL)) {
-			echo '<option selected="selected"'.$desac.'>'.$nom.$txtPb.'</option>';
-		} else {
-			echo '<option'.$desac.'>'.$nom.$txtPb.'</option>';
-		}
+    if(isset($noms)) {
+	    foreach ($noms as $nom) {
+	    	$desac=$txtPb="";
+	    	if (in_array($nom, $nomsPb)) {
+	    		$desac=" disabled";
+	    		//$txtPb=" (adresse inconnue)";
+	    	}
+	    	if (in_array($nom, $tL)) {
+	    		echo '<option selected="selected"'.$desac.'>'.$nom.$txtPb.'</option>';
+	    	} else {
+	    		echo '<option'.$desac.'>'.$nom.$txtPb.'</option>';
+	    	}
+	    }
 	}
 	/// V2.4.7 - OH
 }
@@ -392,14 +394,14 @@ function listeStations($fic,$stationselect) {
 //modification du fichier ecoStations.txt
 function ecritFicEcoStations($hor1, $hor2, $liste1, $liste2) {
 	global $ficEcoStations;
-	
+
 	if (is_array($liste1)) foreach ($liste1 as $_lig1) {
 		if (trim($_lig1)!="") $tL1[]=trim($_lig1);
 	}
 	if (is_array($tL1)) foreach ($tL1 as $_lig1) {
 		$cont1.=$_lig1."\n";
 	}
-	
+
 	if (is_array($liste2)) foreach ($liste2 as $_lig2) {
 		if (trim($_lig2)!="") $tL2[]=trim($_lig2);
 	}
@@ -424,7 +426,7 @@ $cont2";
 //modification du fichier ecoStations_start.txt
 function ecritFicEcoStationstart($hor_start, $jour_start, $tListe, $numlignemodif) {
 	global $ficEcoStationstart;
-	
+
 	//formatage de la liste de stations
 	if (is_array($tListe)) foreach ($tListe as $_lig) {
 		if (trim($_lig)!="") $tL[]=trim($_lig);
@@ -436,13 +438,13 @@ function ecritFicEcoStationstart($hor_start, $jour_start, $tListe, $numlignemodi
 		$fp = fopen($ficEcoStationstart, 'r');
 		$contenu = fread($fp, filesize($ficEcoStationstart));
 		fclose($fp);
- 
+
 		$contenu = explode(PHP_EOL, $contenu);
 		$contenu[$numlignemodif] = "$hor_start|$jour_start|$liste_ligne";
 		$contenu = implode(PHP_EOL, $contenu);
 		$fp = fopen($ficEcoStationstart, 'w');
 		fwrite($fp, $contenu);
-		fclose($fp);	
+		fclose($fp);
 	//création d'une nouvelle ligne
 	} else {
 		//si le fichier n'existe pas
@@ -467,18 +469,18 @@ $hor_start|$jour_start|$liste_ligne";
 //suppression d'une ligne dans le fichier ecoStations_start.txt
 function supprLigneEcoStationstart($numligne,$peda_dmz,$_ip) {
 	global $ficEcoStationstart;
-	
+
 	if($numligne!=0) {// on ne supprime pas l'entête du fichier ie la ligne 0.
 		$fp = fopen($ficEcoStationstart, 'r');
 		$contenu = fread($fp, filesize($ficEcoStationstart));
 		fclose($fp);
- 		
+
 		$contenu = explode(PHP_EOL, $contenu); // PHP_EOL contient le saut à la ligne utilisé sur le serveur (\n linux, \r\n windows ou \r Macintosh
 		foreach($numligne as $val) {
 			unset($contenu[$val]); // On supprime la ou les lignes
 		}
 		$contenu = array_values($contenu); // Ré-indexe l'array
-    
+
 		if(count($contenu)!=1) {//s'il reste plus que la ligne d'entête, on reconstruit le tout et on l'écrit
 			$contenu = implode(PHP_EOL, $contenu);
 			$fp = fopen($ficEcoStationstart, 'w');
@@ -499,12 +501,12 @@ function modifLigneEcoStationstart($numligne) {
 	global $stationplan;
 	global $jourplan;
 	global $verroumodif;
-	
+
 	if($numligne!=0) {// on ne modifie pas l'entête du fichier ie la ligne 0.
 		$fp = fopen($ficEcoStationstart, 'r');
 		$contenu = fread($fp, filesize($ficEcoStationstart));
 		fclose($fp);
-		//affichage des données dans le planificateur 
+		//affichage des données dans le planificateur
 		$contenu = explode(PHP_EOL, $contenu);
 		$valligne = explode("|",$contenu[$numligne[0]]);
 		$horaireplan = $valligne[0];
@@ -548,7 +550,7 @@ function tabplanstart($fichier,$_etat) {
 	global $verroumodif;
 	global $verrouajout;
 	global $verroumodifparam;
-	
+
 	//si une programmation existe, le fichier existe
 	if(file_exists($fichier)) {
 		if(filesize($fichier) != 0) { //si le fichier n'est pas vide
@@ -640,19 +642,27 @@ function copieMachinesdb() {
 	$json = json_decode($contenu);
 	$content = "";
 	foreach($json as $lan => $devices) {
+        	$ip = '';
 		$nom = $devices->id;
-		foreach($devices->hwaddr_interfaces as $addmac){
-			$mac=$addmac;
-		}
-		foreach($devices->ipv4 as $ipv4){
-			$ip=$ipv4;
+		foreach($devices->hwaddr_interfaces as $hwdesc => $addmac){
+			if ($addmac != ":::::" && $addmac != "00:00:00:00:00:00") {
+				$mac=$addmac;
+				foreach($devices->ip4_interfaces as $ipdesc => $ipv4){
+					if ($ipdesc == $hwdesc) {
+						$ip=$ipv4[0];
+						break;
+					}
+				}
+				break;
+			}
 		}
+		if ( $ip == '' ) continue;
 		$content .= $nom.";".$ip.";".$mac."\n";
 	}
 	$id_fichier = fopen($fic,"w");
 	fwrite($id_fichier, $content);
 	fclose($id_fichier);
-	
+
 }
 
 //lance le script qui effectue les modif sur le cron à partir du fichier de config ecoStations.txt
